@@ -556,7 +556,7 @@ final class DispatchingEmitterTest extends Framework\TestCase
             $telemetrySystem,
         );
 
-        $emitter->testAfterTestMethodFinished(
+        $emitter->afterTestMethodFinished(
             $testClassName,
             ...$calledMethods,
         );
@@ -600,7 +600,7 @@ final class DispatchingEmitterTest extends Framework\TestCase
             $telemetrySystem,
         );
 
-        $emitter->testAfterTestMethodCalled(
+        $emitter->afterTestMethodCalled(
             $testClassName,
             $calledMethod,
         );
@@ -646,7 +646,7 @@ final class DispatchingEmitterTest extends Framework\TestCase
 
         $throwable = ThrowableBuilder::from(new Exception('error'));
 
-        $emitter->testAfterTestMethodErrored(
+        $emitter->afterTestMethodErrored(
             $testClassName,
             $calledMethod,
             $throwable,
@@ -695,7 +695,7 @@ final class DispatchingEmitterTest extends Framework\TestCase
             $telemetrySystem,
         );
 
-        $emitter->testAfterLastTestMethodFinished(
+        $emitter->afterLastTestMethodFinished(
             $testClassName,
             ...$calledMethods,
         );
@@ -739,7 +739,7 @@ final class DispatchingEmitterTest extends Framework\TestCase
             $telemetrySystem,
         );
 
-        $emitter->testBeforeFirstTestMethodCalled(
+        $emitter->beforeFirstTestMethodCalled(
             $testClassName,
             $calledMethod,
         );
@@ -785,7 +785,7 @@ final class DispatchingEmitterTest extends Framework\TestCase
 
         $throwable = ThrowableBuilder::from(new Exception('error'));
 
-        $emitter->testAfterLastTestMethodErrored(
+        $emitter->afterLastTestMethodErrored(
             $testClassName,
             $calledMethod,
             $throwable,
@@ -834,7 +834,7 @@ final class DispatchingEmitterTest extends Framework\TestCase
             $telemetrySystem,
         );
 
-        $emitter->testBeforeFirstTestMethodFinished(
+        $emitter->beforeFirstTestMethodFinished(
             $testClassName,
             ...$calledMethods,
         );
@@ -878,7 +878,7 @@ final class DispatchingEmitterTest extends Framework\TestCase
             $telemetrySystem,
         );
 
-        $emitter->testBeforeTestMethodCalled(
+        $emitter->beforeTestMethodCalled(
             $testClassName,
             $calledMethod,
         );
@@ -924,7 +924,7 @@ final class DispatchingEmitterTest extends Framework\TestCase
 
         $throwable = ThrowableBuilder::from(new Exception('error'));
 
-        $emitter->testBeforeTestMethodErrored(
+        $emitter->beforeTestMethodErrored(
             $testClassName,
             $calledMethod,
             $throwable,
@@ -970,7 +970,7 @@ final class DispatchingEmitterTest extends Framework\TestCase
             $telemetrySystem,
         );
 
-        $emitter->testPreConditionCalled(
+        $emitter->preConditionCalled(
             $testClassName,
             $calledMethod,
         );
@@ -1014,7 +1014,7 @@ final class DispatchingEmitterTest extends Framework\TestCase
             $telemetrySystem,
         );
 
-        $emitter->testPostConditionCalled(
+        $emitter->postConditionCalled(
             $testClassName,
             $calledMethod,
         );
@@ -1061,7 +1061,7 @@ final class DispatchingEmitterTest extends Framework\TestCase
             $telemetrySystem,
         );
 
-        $emitter->testPostConditionFinished(
+        $emitter->postConditionFinished(
             $testClassName,
             ...$calledMethods,
         );
@@ -1108,7 +1108,7 @@ final class DispatchingEmitterTest extends Framework\TestCase
             $telemetrySystem,
         );
 
-        $emitter->testBeforeTestMethodFinished(
+        $emitter->beforeTestMethodFinished(
             $testClassName,
             ...$calledMethods,
         );
@@ -1155,7 +1155,7 @@ final class DispatchingEmitterTest extends Framework\TestCase
             $telemetrySystem,
         );
 
-        $emitter->testPreConditionFinished(
+        $emitter->preConditionFinished(
             $testClassName,
             ...$calledMethods,
         );
@@ -1199,7 +1199,7 @@ final class DispatchingEmitterTest extends Framework\TestCase
             $telemetrySystem,
         );
 
-        $emitter->testAfterLastTestMethodCalled(
+        $emitter->afterLastTestMethodCalled(
             $testClassName,
             $calledMethod,
         );
